#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['teenypm']

package_data = \
{'': ['*']}

install_requires = \
['colorama', 'dateparser', 'humanize']

entry_points = \
{'console_scripts': ['pm = teenypm:main']}

setup(name='teenypm',
      version='0.1.6',
      description='A teeny CLI project manager',
      author='Joe Trewin',
      author_email='joe.trewin@gmail.com',
      url='https://github.com/joeyspacerocks/pm',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
     )
